
package com.reactlibrary;

import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.Callback;
import android.widget.Toast;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import com.itep.device.thermalPrinter.ThermalPrinterInterface;
import com.itep.device.thermalPrinter.ThremalPrinterException;
import com.itep.device.util.CreateBarCode;
import com.itep.device.util.HexDump;

public class RNLotteryPrinterModule extends ReactContextBaseJavaModule {

  private final ReactApplicationContext reactContext;

  private static final String LOG_TAG = "ThermalPrinter";

  ExecutorService es = Executors.newScheduledThreadPool(30);
  private ThermalPrinterInterface  pos;

  private static final String DURATION_SHORT_KEY = "SHORT";
  private static final String DURATION_LONG_KEY = "LONG";

  public RNLotteryPrinterModule(ReactApplicationContext reactContext) {
    super(reactContext);
    this.reactContext = reactContext;
    pos = new ThermalPrinterInterface();
  }

  @Override
  public String getName() {
    return "RNLotteryPrinter";
  }

  @Override
  public Map<String, Object> getConstants() {
      final Map<String, Object> constants = new HashMap<>();
      constants.put(DURATION_SHORT_KEY, Toast.LENGTH_SHORT);
      constants.put(DURATION_LONG_KEY, Toast.LENGTH_LONG);
      return constants;
  }

  @ReactMethod
  public void thermalOpen(int duration) {
    int i = pos.open();

    String message  = HexDump.toHexString(i);
    Toast.makeText(getReactApplicationContext(), message, duration).show();
  }

  @ReactMethod
  public void thermalClose(int duration) {
    int i = pos.close();

    String message  = HexDump.toHexString(i);
    Toast.makeText(getReactApplicationContext(), message, duration).show();
  }

  @ReactMethod
  public void thermalFeedPaper(int duration) {
    int i = pos.feedPaper(100, 10);

    String message  = String.format("thermalFeedPaper Error Code:%08X", i);
    Toast.makeText(getReactApplicationContext(), message, duration).show();
  }

  @ReactMethod
  public void printSample(int duration) {

    ThermalPrinterInterface thermalPrinterInterface = new ThermalPrinterInterface();
    thermalPrinterInterface.open();

    CreateBarCode createBarCode = new CreateBarCode();
    int ret;

    try {

          thermalPrinterInterface.printBmp(createBarCode.createBarCode("Printer Test",380,100), 0, 0, 5);
          thermalPrinterInterface.setFontSize(3);
          thermalPrinterInterface.setFontAlignment("left");
          ret = thermalPrinterInterface.printStr("Printer Test", false, false, 5);
          thermalPrinterInterface.setFontSize(3);
          thermalPrinterInterface.setFontAlignment("left");
          ret = thermalPrinterInterface.printStr("prueba de la impresora", false, false, 5);
          thermalPrinterInterface.printBmp(createBarCode.createQRCode("Printer Test",200,200), 90, 0, 5);
          ret = thermalPrinterInterface.feedPaper(150, 10);
          if (ret != 0) {
              throw new ThremalPrinterException(ret);
          } else {
              String message  = "print success";
              Toast.makeText(getReactApplicationContext(), message, duration).show();
          }
      }catch (ThremalPrinterException e) {

          String message  = "Print failed:" + e.getMessage() + "\n" + e.getLocalizedMessage();
          Toast.makeText(getReactApplicationContext(), message, duration).show();
          e.printStackTrace();
          thermalPrinterInterface.close();
      } catch (Exception e) {
          e.printStackTrace();
          thermalPrinterInterface.close();
      }

  }
}
